package cn.iocoder.yudao.module.inspection.mapper;

import java.util.List;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import cn.iocoder.yudao.module.inspection.entity.InspectionPickCar;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;

/**
 * 上门取车服务Mapper接口
 *
 * @author 朱春云
 * @date 2023-09-02
 */
@Mapper
public interface InspectionPickCarMapper  extends BaseMapper<InspectionPickCar>
{
    /**
     * 查询上门取车服务
     *
     * @param id 上门取车服务主键
     * @return 上门取车服务
     */
    public InspectionPickCar selectInspectionPickCarById(Long id);

    /**
     * 查询上门取车服务列表
     *
     * @param inspectionPickCar 上门取车服务
     * @return 上门取车服务集合
     */
    public IPage<InspectionPickCar> selectInspectionPickCarList(Page<InspectionPickCar> page, @Param("vo") InspectionPickCar inspectionPickCar);

    /**
     * 新增上门取车服务
     *
     * @param inspectionPickCar 上门取车服务
     * @return 结果
     */
    public int insertInspectionPickCar(InspectionPickCar inspectionPickCar);

    /**
     * 修改上门取车服务
     *
     * @param inspectionPickCar 上门取车服务
     * @return 结果
     */
    public int updateInspectionPickCar(InspectionPickCar inspectionPickCar);

    /**
     * 删除上门取车服务
     *
     * @param id 上门取车服务主键
     * @return 结果
     */
    public int deleteInspectionPickCarById(Long id);

    /**
     * 批量删除上门取车服务
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteInspectionPickCarByIds(Long[] ids);
}
